Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecodeJwtSecretBase64 ¶ added in v1.27.0
DecodeJwtSecretBase64 decodes a base64 encoded jwt secret into bytes, and check its length
func NewInternalToken ¶
NewInternalToken generate a new value intended to be used by INTERNAL_TOKEN.
func NewJwtSecretWithBase64 ¶ added in v1.27.0
NewJwtSecretWithBase64 generates a jwt secret with its base64 encoded value intended to be used for saving into config file
func NewSecretKey ¶
NewSecretKey generate a new value intended to be used by SECRET_KEY.
Types ¶
type SSHKeyType ¶ added in v1.27.0
type SSHKeyType string
const ( SSHKeyRSA SSHKeyType = "rsa" SSHKeyECDSA SSHKeyType = "ecdsa" SSHKeyED25519 SSHKeyType = "ed25519" )
Click to show internal directories.
Click to hide internal directories.